pub fn channel() -> Result<(Sender, PyReceiver), Error>Expand description
Create a new channel with a Rust sender and a Python receiver.
pub fn channel() -> Result<(Sender, PyReceiver), Error>Create a new channel with a Rust sender and a Python receiver.