pub trait IntoPyObjectBox: Send {
// Required method
fn into_py_object(self: Box<Self>, py: Python<'_>) -> PyResult<Py<PyAny>>;
}Expand description
A blanket trait used to convert boxed objects into python objects.
pub trait IntoPyObjectBox: Send {
// Required method
fn into_py_object(self: Box<Self>, py: Python<'_>) -> PyResult<Py<PyAny>>;
}A blanket trait used to convert boxed objects into python objects.